@@ -1,14 +1,14 @@
 package Gtk2::Box;
 
-# $Id: Box.pm,v 1.6 2002/11/28 13:55:27 ggc Exp $
+# $Id: Box.pm,v 1.7 2002/12/16 17:07:31 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Box.pm,v 1.6 2002/11/28 13:55:27 ggc Exp $';
+our $rcsid = '$Id: Box.pm,v 1.7 2002/12/16 17:07:31 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::Container;
 @ISA=qw(Gtk2::Container);
