@@ -1,14 +1,14 @@
 package Gtk2::Button;
 
-# $Id: Button.pm,v 1.9 2002/11/12 20:29:23 gthyni Exp $
+# $Id: Button.pm,v 1.10 2002/12/16 17:07:59 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Button.pm,v 1.9 2002/11/12 20:29:23 gthyni Exp $';
+our $rcsid = '$Id: Button.pm,v 1.10 2002/12/16 17:07:59 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::Bin;
 @ISA = qw(Gtk2::Bin);
