@@ -1,14 +1,14 @@
 package Gtk2::Gdk::Color;
 
-# $Id: Color.pm,v 1.6 2002/11/12 16:20:53 ggc Exp $
+# $Id: Color.pm,v 1.7 2002/12/16 17:24:09 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Color.pm,v 1.6 2002/11/12 16:20:53 ggc Exp $';
+our $rcsid = '$Id: Color.pm,v 1.7 2002/12/16 17:24:09 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::_Boxed;
 @ISA = qw(Gtk2::_Boxed);
