@@ -1,14 +1,14 @@
 package Gtk2::Gdk::Visual;
 
-# $Id: Visual.pm,v 1.1 2002/11/27 23:19:55 gthyni Exp $
+# $Id: Visual.pm,v 1.2 2002/12/16 17:24:32 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Visual.pm,v 1.1 2002/11/27 23:19:55 gthyni Exp $';
+our $rcsid = '$Id: Visual.pm,v 1.2 2002/12/16 17:24:32 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use base qw(Gtk2::_Object);
 
