@@ -1,14 +1,14 @@
 package Gtk2::ListStore;
 
-# $Id: ListStore.pm,v 1.10 2002/11/22 14:38:02 ggc Exp $
+# $Id: ListStore.pm,v 1.12 2002/12/16 17:20:47 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: ListStore.pm,v 1.10 2002/11/22 14:38:02 ggc Exp $';
+our $rcsid = '$Id: ListStore.pm,v 1.12 2002/12/16 17:20:47 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::TreeModel;
 @ISA = ('Gtk2::TreeModel');
@@ -28,7 +28,7 @@ sub new
 # Append a new row, set the values, return the TreeIter
 sub append_set {
     my ($model, $values) = @_;
-    my $iter = Gtk2::TreeIter->new();
+    my $iter = Gtk2::TreeIter->new;
     $model->append($iter);
     $model->set($iter, $values);
     return $iter;
