@@ -1,13 +1,13 @@
 package Gtk2::Pango::FontDescription;
 
-# $Id: FontDescription.pm,v 1.8 2002/11/13 11:38:00 ggc Exp $
+# $Id: FontDescription.pm,v 1.9 2002/12/16 17:24:39 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: FontDescription.pm,v 1.8 2002/11/13 11:38:00 ggc Exp $';
+our $rcsid = '$Id: FontDescription.pm,v 1.9 2002/12/16 17:24:39 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 1;
