@@ -1,14 +1,14 @@
 package Gtk2::Text;
 
-# $Id: Text.pm,v 1.2 2002/11/20 19:30:03 gthyni Exp $
+# $Id: Text.pm,v 1.3 2002/12/16 17:22:48 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Text.pm,v 1.2 2002/11/20 19:30:03 gthyni Exp $';
+our $rcsid = '$Id: Text.pm,v 1.3 2002/12/16 17:22:48 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use base qw(Gtk2::OldEditable);
 
