@@ -1,4 +1,4 @@
-/* $Id: Arrow.c,v 1.5 2002/10/21 11:41:23 ggc Exp $
+/* $Id: Arrow.c,v 1.6 2003/01/16 21:24:03 joered Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -9,7 +9,7 @@
 
 #include "gtk2-perl.h"
 
-SV* gtkperl_arrow_new(char* class, SV* arrow_type, SV* shadow_type)
+SV* gtkperl_arrow__new(char* class, SV* arrow_type, SV* shadow_type)
 {
     return gtk2_perl_new_object(gtk_arrow_new(SvGtkArrowType(arrow_type), SvGtkShadowType(shadow_type)));
 }
