@@ -1,4 +1,4 @@
-/* $Id: Bin.c,v 1.3 2002/11/03 07:39:36 glade-perl Exp $
+/* $Id: Bin.c,v 1.4 2003/02/03 10:57:33 ggc Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -8,6 +8,6 @@
 
 SV* gtkperl_bin_get_child(SV *bin)
 {
-    return gtk2_perl_new_object(gtk_bin_get_child(SvGtkBin(bin)));
+    return gtk2_perl_new_object_nullok(gtk_bin_get_child(SvGtkBin(bin)));
 }
 
